==> haskell-skylighting-format-blaze-html-0.1.1.3-114-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-3Ishv6xMglDCPYQ3mHDGCC

key:
    skylighting-format-blaze-html-0.1.1.3-3Ishv6xMglDCPYQ3mHDGCC

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  9c4fd5a8854a71452af5e65c11111151
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-3Ishv6xMglDCPYQ3mHDGCC

depends:
    base-4.17.2.1 blaze-html-0.9.2.0-BsVDj7UmD9SGJonPOQFUuj
    containers-0.6.7 skylighting-core-0.14.2-DB3Bg6HHgy674FCTp1eWcE
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-blaze-html-0.1.1.3-134-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-CWzGO997nmJ6ffPeiFR8JV

key:
    skylighting-format-blaze-html-0.1.1.3-CWzGO997nmJ6ffPeiFR8JV

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  5f5065c68fa5c47e7c4df7469bce8414
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-CWzGO997nmJ6ffPeiFR8JV

depends:
    base-4.17.2.1 blaze-html-0.9.2.0-3cSCYM9QSR99BQnVHXrYzE
    containers-0.6.7 skylighting-core-0.14.3-3942VFqpxT92bo8sB6TPZ4
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
